==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectExpression.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectexpression_h
#define objectexpression_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
typedef enum {
  adms_expression_enumeration_static_no,
  adms_expression_enumeration_static_yes
} e_expression_static;
win32_interface char* adms_expression_tostring_static_impl (p_admsttransform myadmsttransform,e_expression_static e);
win32_interface e_expression_static adms_expression_fromstring_static_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_expression_enumeration_hasVoltageDependentFunction_no,
  adms_expression_enumeration_hasVoltageDependentFunction_yes
} e_expression_hasVoltageDependentFunction;
win32_interface char* adms_expression_tostring_hasVoltageDependentFunction_impl (p_admsttransform myadmsttransform,e_expression_hasVoltageDependentFunction e);
win32_interface e_expression_hasVoltageDependentFunction adms_expression_fromstring_hasVoltageDependentFunction_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_expression_enumeration_TemperatureDependent_no,
  adms_expression_enumeration_TemperatureDependent_yes
} e_expression_TemperatureDependent;
win32_interface char* adms_expression_tostring_TemperatureDependent_impl (p_admsttransform myadmsttransform,e_expression_TemperatureDependent e);
win32_interface e_expression_TemperatureDependent adms_expression_fromstring_TemperatureDependent_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_expression_enumeration_dynamic_no,
  adms_expression_enumeration_dynamic_yes
} e_expression_dynamic;
win32_interface char* adms_expression_tostring_dynamic_impl (p_admsttransform myadmsttransform,e_expression_dynamic e);
win32_interface e_expression_dynamic adms_expression_fromstring_dynamic_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_expression_enumeration_value_is_any,
  adms_expression_enumeration_value_is_neg_one,
  adms_expression_enumeration_value_is_one,
  adms_expression_enumeration_value_is_zero
} e_expression_value;
win32_interface char* adms_expression_tostring_value_impl (p_admsttransform myadmsttransform,e_expression_value e);
win32_interface e_expression_value adms_expression_fromstring_value_impl (p_admsttransform myadmsttransform,char*token);
struct s_expression {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  gpointer _tree;
  int _tree_isdefault : 1;
  char* _hasspecialnumber;
  int _hasspecialnumber_isdefault : 1;
  e_expression_static _static;
  int _static_isdefault : 1;
  e_expression_hasVoltageDependentFunction _hasVoltageDependentFunction;
  int _hasVoltageDependentFunction_isdefault : 1;
  e_expression_TemperatureDependent _TemperatureDependent;
  int _TemperatureDependent_isdefault : 1;
  e_expression_dynamic _dynamic;
  int _dynamic_isdefault : 1;
  e_expression_value _value;
  int _value_isdefault : 1;
  GSList* _function;
  int _function_isdefault : 1;
  GSList* _probe;
  int _probe_isdefault : 1;
  GSList* _variable;
  int _variable_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectFunction.h>
#include <admsObject/objectProbe.h>
#include <admsObject/objectVariable.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_expression_getuid (p_expression myexpression);
win32_interface gboolean adms_expression_cmp (p_expression myexpression,p_expression refexpression);
win32_interface p_expression adms_expression_new_1 (p_module mymodule,gpointer mytree);
#define adms_expression_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_expression_free(item)\
{\
  free(item->_hasspecialnumber);\
  free(item);\
}
win32_interface p_adms adms_expression_new_impl (p_adms arguments[]);
win32_interface p_expression adms_expression_impl (void* member);
#define adms_expression(member) ((p_expression) (member))
#define adms_expression_new adms_expression_new_1
#define adms_expression_isdefault_module(expression) (adms_expression(expression)->_module_isdefault)
#define adms_expression_valueof_module(expression) (adms_expression(expression)->_module)
#define adms_expression_isdefault_tree(expression) (adms_expression(expression)->_tree_isdefault)
#define adms_expression_valueof_tree(expression) (adms_expression(expression)->_tree)
#define adms_expression_isdefault_hasspecialnumber(expression) (adms_expression(expression)->_hasspecialnumber_isdefault)
#define adms_expression_valueof_hasspecialnumber(expression) (adms_expression(expression)->_hasspecialnumber)
#define adms_expression_isdefault_static(expression) (adms_expression(expression)->_static_isdefault)
#define adms_expression_valueof_static(expression) (adms_expression(expression)->_static)
#define adms_expression_isdefault_hasVoltageDependentFunction(expression) (adms_expression(expression)->_hasVoltageDependentFunction_isdefault)
#define adms_expression_valueof_hasVoltageDependentFunction(expression) (adms_expression(expression)->_hasVoltageDependentFunction)
#define adms_expression_isdefault_TemperatureDependent(expression) (adms_expression(expression)->_TemperatureDependent_isdefault)
#define adms_expression_valueof_TemperatureDependent(expression) (adms_expression(expression)->_TemperatureDependent)
#define adms_expression_isdefault_dynamic(expression) (adms_expression(expression)->_dynamic_isdefault)
#define adms_expression_valueof_dynamic(expression) (adms_expression(expression)->_dynamic)
#define adms_expression_isdefault_value(expression) (adms_expression(expression)->_value_isdefault)
#define adms_expression_valueof_value(expression) (adms_expression(expression)->_value)
#define adms_expression_isdefault_function(expression) (adms_expression(expression)->_function_isdefault)
#define adms_expression_valueof_function(expression) (adms_expression(expression)->_function)
#define adms_expression_isdefault_probe(expression) (adms_expression(expression)->_probe_isdefault)
#define adms_expression_valueof_probe(expression) (adms_expression(expression)->_probe)
#define adms_expression_isdefault_variable(expression) (adms_expression(expression)->_variable_isdefault)
#define adms_expression_valueof_variable(expression) (adms_expression(expression)->_variable)
#define adms_expression_valueof_math(expression) ((p_math)expression)
#define adms_expression_valueof_adms(expression) ((p_adms)expression)
#define adms_expression_valueto_module(a,b) ((p_expression)a)->_module=(b)
win32_interface void adms_expression_valueto_module_impl (p_expression myexpression,p_module _module);
#define adms_expression_valueto_tree(a,b) ((p_expression)a)->_tree=(b)
win32_interface void adms_expression_valueto_tree_impl (p_expression myexpression,gpointer _tree);
#define adms_expression_valueto_hasspecialnumber(a,b) ((p_expression)a)->_hasspecialnumber=(b)
win32_interface void adms_expression_valueto_hasspecialnumber_impl (p_expression myexpression,char* _hasspecialnumber);
#define adms_expression_valueto_static(a,b) ((p_expression)a)->_static=(b)
win32_interface void adms_expression_valueto_static_impl (p_expression myexpression,e_expression_static _static);
#define adms_expression_valueto_hasVoltageDependentFunction(a,b) ((p_expression)a)->_hasVoltageDependentFunction=(b)
win32_interface void adms_expression_valueto_hasVoltageDependentFunction_impl (p_expression myexpression,e_expression_hasVoltageDependentFunction _hasVoltageDependentFunction);
#define adms_expression_valueto_TemperatureDependent(a,b) ((p_expression)a)->_TemperatureDependent=(b)
win32_interface void adms_expression_valueto_TemperatureDependent_impl (p_expression myexpression,e_expression_TemperatureDependent _TemperatureDependent);
#define adms_expression_valueto_dynamic(a,b) ((p_expression)a)->_dynamic=(b)
win32_interface void adms_expression_valueto_dynamic_impl (p_expression myexpression,e_expression_dynamic _dynamic);
#define adms_expression_valueto_value(a,b) ((p_expression)a)->_value=(b)
win32_interface void adms_expression_valueto_value_impl (p_expression myexpression,e_expression_value _value);
#define adms_expression_valueto_function(a,b) ((p_expression)a)->_function=(b)
win32_interface void adms_expression_valueto_function_impl (p_expression myexpression,GSList* _function);
win32_interface p_function adms_expression_list_function_lookup_by_id (p_expression mymyexpression,char* myname,int myunique_id);
win32_interface p_function adms_expression_list_function_prepend_by_id (p_expression mymyexpression,char* myname,int myunique_id);
win32_interface p_function adms_expression_list_function_prepend_by_id_once_or_ignore (p_expression mymyexpression,char* myname,int myunique_id);
win32_interface void adms_expression_list_function_prepend (p_expression mymyexpression,p_function myfunction);
#define adms_expression_valueto_probe(a,b) ((p_expression)a)->_probe=(b)
win32_interface void adms_expression_valueto_probe_impl (p_expression myexpression,GSList* _probe);
win32_interface p_probe adms_expression_list_probe_lookup_by_id (p_expression mymyexpression,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface p_probe adms_expression_list_probe_prepend_by_id (p_expression mymyexpression,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface p_probe adms_expression_list_probe_prepend_by_id_once_or_ignore (p_expression mymyexpression,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface void adms_expression_list_probe_prepend_once_or_ignore (p_expression mymyexpression,p_probe myprobe);
#define adms_expression_valueto_variable(a,b) ((p_expression)a)->_variable=(b)
win32_interface void adms_expression_valueto_variable_impl (p_expression myexpression,GSList* _variable);
win32_interface p_variable adms_expression_list_variable_lookup_by_id (p_expression mymyexpression,p_module mymodule,char* myname,gpointer myblock);
win32_interface p_variable adms_expression_list_variable_prepend_by_id (p_expression mymyexpression,p_module mymodule,char* myname,gpointer myblock);
win32_interface p_variable adms_expression_list_variable_prepend_by_id_once_or_ignore (p_expression mymyexpression,p_module mymodule,char* myname,gpointer myblock);
win32_interface void adms_expression_list_variable_prepend_once_or_ignore (p_expression mymyexpression,p_variable myvariable);
#endif /* objectexpression_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectExpression.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectexpression_h
#define objectexpression_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
typedef enum {
  adms_expression_enumeration_hasVoltageDependentFunction_no,
  adms_expression_enumeration_hasVoltageDependentFunction_yes
} e_expression_hasVoltageDependentFunction;
win32_interface char* adms_expression_tostring_hasVoltageDependentFunction_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_expression_hasVoltageDependentFunction adms_expression_fromstring_hasVoltageDependentFunction_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_expression_enumeration_TemperatureDependent_no,
  adms_expression_enumeration_TemperatureDependent_yes
} e_expression_TemperatureDependent;
win32_interface char* adms_expression_tostring_TemperatureDependent_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_expression_TemperatureDependent adms_expression_fromstring_TemperatureDependent_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_expression_enumeration_value_is_any,
  adms_expression_enumeration_value_is_neg_one,
  adms_expression_enumeration_value_is_one,
  adms_expression_enumeration_value_is_zero
} e_expression_value;
win32_interface char* adms_expression_tostring_value_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_expression_value adms_expression_fromstring_value_impl (p_admsttransform myadmsttransform,char*token);
struct s_expression {
  t_math _math;
  p_module _module;
  int _module_isdefault : 1;
  p_adms _tree;
  int _tree_isdefault : 1;
  p_quark _hasspecialnumber;
  int _hasspecialnumber_isdefault : 1;
  p_enumeration _hasVoltageDependentFunction;
  int _hasVoltageDependentFunction_isdefault : 1;
  p_enumeration _TemperatureDependent;
  int _TemperatureDependent_isdefault : 1;
  p_enumeration _value;
  int _value_isdefault : 1;
  p_slist _function;
  int _function_isdefault : 1;
  p_slist _probe;
  int _probe_isdefault : 1;
  p_slist _variable;
  int _variable_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectQuark.h>
#include <admsObject/objectEnumeration.h>
#include <admsObject/objectFunction.h>
#include <admsObject/objectProbe.h>
#include <admsObject/objectVariable.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_expression_uid (p_expression myexpression);
win32_interface int adms_expression_cmp (p_expression myexpression,p_expression refexpression);
win32_interface p_expression adms_expression_new(p_module mymodule,p_adms mytree);
win32_interface p_adms adms_expression_new_impl (p_adms arguments[]);
#define adms_expression(member) ((p_expression) (member))
#define adms_expression_isdefault_module(expression) (adms_expression(expression)->_module_isdefault)
#define adms_expression_valueof_module(expression) (adms_expression(expression)->_module)
#define adms_expression_isdefault_tree(expression) (adms_expression(expression)->_tree_isdefault)
#define adms_expression_valueof_tree(expression) (adms_expression(expression)->_tree)
#define adms_expression_isdefault_hasspecialnumber(expression) (adms_expression(expression)->_hasspecialnumber_isdefault)
#define adms_expression_valueof_hasspecialnumber(expression) (adms_expression(expression)->_hasspecialnumber)
#define adms_expression_isdefault_hasVoltageDependentFunction(expression) (adms_expression(expression)->_hasVoltageDependentFunction_isdefault)
#define adms_expression_valueof_hasVoltageDependentFunction(expression) (adms_expression(expression)->_hasVoltageDependentFunction)
#define adms_expression_isdefault_TemperatureDependent(expression) (adms_expression(expression)->_TemperatureDependent_isdefault)
#define adms_expression_valueof_TemperatureDependent(expression) (adms_expression(expression)->_TemperatureDependent)
#define adms_expression_isdefault_value(expression) (adms_expression(expression)->_value_isdefault)
#define adms_expression_valueof_value(expression) (adms_expression(expression)->_value)
#define adms_expression_isdefault_function(expression) (adms_expression(expression)->_function_isdefault)
#define adms_expression_valueof_function(expression) (adms_expression(expression)->_function)
#define adms_expression_isdefault_probe(expression) (adms_expression(expression)->_probe_isdefault)
#define adms_expression_valueof_probe(expression) (adms_expression(expression)->_probe)
#define adms_expression_isdefault_variable(expression) (adms_expression(expression)->_variable_isdefault)
#define adms_expression_valueof_variable(expression) (adms_expression(expression)->_variable)
#define adms_expression_valueof_math(expression) ((p_math)expression)
#define adms_expression_valueof_adms(expression) ((p_adms)expression)
win32_interface inline void adms_expression_valueto_module (p_expression myexpression,p_module _module);
win32_interface inline void adms_expression_valueto_tree (p_expression myexpression,p_adms _tree);
win32_interface inline void adms_expression_valueto_hasspecialnumber (p_expression myexpression,p_quark _hasspecialnumber);
win32_interface inline void adms_expression_valueto_hasVoltageDependentFunction (p_expression myexpression,p_enumeration _hasVoltageDependentFunction);
win32_interface inline void adms_expression_valueto_TemperatureDependent (p_expression myexpression,p_enumeration _TemperatureDependent);
win32_interface inline void adms_expression_valueto_value (p_expression myexpression,p_enumeration _value);
win32_interface inline void adms_expression_valueto_function (p_expression myexpression,p_slist _function);
win32_interface p_function adms_expression_list_function_lookup_by_id (p_expression mymyexpression,p_quark myname,p_integer myunique_id);
win32_interface p_function adms_expression_list_function_prepend_by_id (p_expression mymyexpression,p_quark myname,p_integer myunique_id);
win32_interface p_function adms_expression_list_function_prepend_by_id_once_or_ignore (p_expression mymyexpression,p_quark myname,p_integer myunique_id);
win32_interface void adms_expression_list_function_prepend (p_expression mymyexpression,p_function myfunction);
win32_interface inline void adms_expression_valueto_probe (p_expression myexpression,p_slist _probe);
win32_interface p_probe adms_expression_list_probe_lookup_by_id (p_expression mymyexpression,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface p_probe adms_expression_list_probe_prepend_by_id (p_expression mymyexpression,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface p_probe adms_expression_list_probe_prepend_by_id_once_or_ignore (p_expression mymyexpression,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface void adms_expression_list_probe_prepend_once_or_ignore (p_expression mymyexpression,p_probe myprobe);
win32_interface inline void adms_expression_valueto_variable (p_expression myexpression,p_slist _variable);
win32_interface p_variable adms_expression_list_variable_lookup_by_id (p_expression mymyexpression,p_module mymodule,p_quark myname,p_adms myblock);
win32_interface p_variable adms_expression_list_variable_prepend_by_id (p_expression mymyexpression,p_module mymodule,p_quark myname,p_adms myblock);
win32_interface p_variable adms_expression_list_variable_prepend_by_id_once_or_ignore (p_expression mymyexpression,p_module mymodule,p_quark myname,p_adms myblock);
win32_interface void adms_expression_list_variable_prepend_once_or_ignore (p_expression mymyexpression,p_variable myvariable);
win32_interface inline void adms_expression_free(p_expression myexpression);
#endif /* objectexpression_h */
